@@ -1,8 +1,8 @@
 # Fit function per group:
 maxLikEstimator_Gauss_group <- function(S,kappa,means,mu,sigma,...){
-
     # nvar <- ncol(kappa) 
-  res <-  sum(diag(S %*% kappa)) + t(means - mu) %*% kappa %*% (means - mu)  - log(det(kappa))
+  # res <-  sum(diag(S %*% kappa)) + t(means - mu) %*% kappa %*% (means - mu)  - log(det(kappa))
+  res <-  sum(diag(S %*% kappa)) + t(means - mu) %*% kappa %*% (means - mu) - determinant(kappa, TRUE)$modulus
   
   as.numeric(res)
 }
@@ -15,4 +15,4 @@ maxLikEstimator_Gauss <- function(prep){
 
   # Sum and return:
   sum(fit_per_group)
-}
\ No newline at end of file
+}
